@@ -3,9 +3,15 @@
 #include <signal.h>
 #include <errno.h>
 
+int syscall(int number, ...);
+int pop_fd(int fd,int rw);
+int top_fd(int fd,int rw);
+int porting_dbg(const char *fmt,...);
+int PollIn1(int fd,int timeout);
+int get_writelimit(int,int);
+
 static int inread;
-read(fd,buf,siz)
-	char *buf;
+int read(int fd,void *buf,int siz)
 {	int rcc;
 
 	rcc = syscall(SYS_read,fd,buf,siz);
@@ -26,10 +32,14 @@ if( inread <= 1 ) porting_dbg("pop_fd read(%d) = %d",fd,rcc);
 	return rcc;
 }
 static int inwrite;
-write(fd,buf,siz)
-	char *buf;
+int write(int fd,const void *buf,int siz)
 {	int wcc;
-	void (*osig);
+	void (*osig)(int);
+
+/*
+	if( inwrite == 0 )
+		siz = get_writelimit(fd,siz);
+*/
 
 	if( inwrite || top_fd(fd,1) < 0 )
 		return syscall(SYS_write,fd,buf,siz);
